@@ -2,8 +2,16 @@ package m
 
 import "fmt"
 
-// Formats a number into a string with _ between each three-group of digits
+// Formats a number into a string with _ between each three-group of digits, for
+// numbers >= 10_000.
+//
+// Regarding the >= 10_000 exception:
+// https://en.wikipedia.org/wiki/Decimal_separator#Exceptions_to_digit_grouping
 func formatNumber(number uint) string {
+	if number < 10_000 {
+		return fmt.Sprint(number)
+	}
+
 	result := ""
 
 	chars := []rune(fmt.Sprint(number))
